Job<Q, R> class

a job for execution on an Executor

Constructors

Job(String name, ComputeCallback<Q, R> computeFunction, Q value, {CancellationCallback? cancelled, required String? deduplicationKey})

Properties

cancelled → CancellationCallback?
a callback that indicates if the job is cancelled
final
computeFunction → ComputeCallback<Q, R>
the fuction that computes the result
final
deduplicationKey → String?
jobs with the same deduplication key are only executed once, the result is passed to all jobs having the same key
final
hashCode → int
The hash code for this object.
no setterinherited
isCancelled → bool
no setter
name → String
the name of the job, for diagnostics
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Q
the input value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited